MultipleSearchController<T> class

This is the controller for the MultipleSearchSelection.

Use this controller to :

  1. getAllItems
  2. getPickedItems
  3. searchItems
  4. clearSearchField
  5. clearAllPickedItems
  6. selectAllItems

Constructors

MultipleSearchController({int? minCharsToShowItems, bool allowDuplicateSelection = true, bool isSelectable = false})

Properties

allowDuplicateSelection bool
Whether to allow an already picked item to be picked again.
getter/setter pair
clearAllPickedItemsCallback ↔ dynamic Function()?
getter/setter pair
clearSearchFieldCallback ↔ dynamic Function()?
getter/setter pair
getAllItemsCallback List<T> Function()?
getter/setter pair
getPickedItemsCallback List<T> Function()?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isSelectable bool
Whether the widget has 'selectable' style. In this style when you select an item it will NOT be removed from the showed items list.
final
minCharsToShowItems int?
The minimum number of characters to type before showing items.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchItemsCallback List<T> Function(String)?
getter/setter pair
selectAllItemsCallback ↔ dynamic Function()?
getter/setter pair

Methods

clearAllPickedItems() → void
Clear all picked items.
clearSearchField() → void
Clear the search field.
getAllItems() List<T>
Returns all items in the list.
getPickedItems() List<T>
Returns the picked items.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
searchItems(String term) List<T>
Search all items in the list.
selectAllItems() → void
Select all items in the list.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited